package com.lantone.common.util;

import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.time.DateUtils;

import java.text.ParseException;
import java.util.Date;

/**
 * @Description: 字符串有关帮助类 封装了第三方帮助类
 * @author: gaodm
 * @time: 2018/8/6 11:15
 */
public class StringUtil {
    /**
     * 判断某字符串是否为空或长度为0或由空白符(whitespace) 构成
     *
     * @param str 需要判断的字符串
     * @return
     */
    public static boolean isBlank(String str) {
        return StringUtils.isBlank(str);
    }

    /**
     * 判断某字符串是否不是为空或长度为0或由空白符(whitespace) 构成
     *
     * @param str 需要判断的字符串
     * @return
     */
    public static boolean isNotBlank(String str) {
        return StringUtils.isNotBlank(str);
    }

    /**
     * 判断某字符串是否为空，为空的标准是 str==null 或 str.length()==0
     *
     * @param str 需要判断的字符串
     * @return
     */
    public static boolean isEmpty(String str) {
        return StringUtils.isEmpty(str);
    }

    /**
     * 判断某字符串是否不为空，为空的标准是 str==null 或 str.length()==0
     *
     * @param str 需要判断的字符串
     * @return
     */
    public static boolean isNotEmpty(String str) {
        return StringUtils.isNotEmpty(str);
    }

    /**
     * 判断两个字符串是否相同
     *
     * @param arg1
     * @param arg2
     * @return
     */
    public static boolean equals(String arg1, String arg2) {
        return StringUtils.equals(arg1, arg2);
    }

    /**
     * 清除字符串中的空白
     *
     * @param str
     * @return
     */
    public static String removeBlank(String str) {
        if (isBlank(str)) {
            return str;
        }
        return str.replaceAll("[\\s\\p{Zs}]", "");
    }

    /**
     * 解析时间
     *
     * @param datetime
     * @return
     */
    public static Date parseDateTime(String datetime) {
        Date date = null;
        try {
            datetime = remove_ctl(datetime);

            if (datetime.contains("至")) {
                datetime = datetime.split("至")[1].replaceAll("[\\u4e00-\\u9fa5]", "");
            }

            if (datetime.length() > 0) {
                date = DateUtils.parseDate(datetime, DateUtil.dateFormats);
            }
        } catch (ParseException ex) {
            ex.printStackTrace();
        }
        return date;
    }

    /**
     * 删除字符串中的换行和控制字符
     *
     * @param str
     */
    public static String remove_ctl(String str) {
        String trim = "";
        if(StringUtils.isNotEmpty(str)){
            trim = str.replaceAll("\r|\n|\r\n|/r/n", "").trim();
        }
        return trim;
    }

}